@@ -28,6 +28,8 @@ from sarpy.io.complex.sicd_elements.SICD import SICDType
 
 logger = logging.getLogger(__name__)
 
+_sicd_type_text = 'Requires instance of SICDType,\n\tgot type `{}`'
+
 
 class TxRcvPolarizationType(Serializable):
     """
@@ -197,7 +199,7 @@ class ExploitationFeaturesCollectionInformationType(Serializable):
         """
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
 
         polarizations = [
             TxRcvPolarizationType.from_sicd_value(entry.TxRcvPolarization)
@@ -424,7 +426,7 @@ class ExploitationFeaturesProductType(Serializable):
         """
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
 
         row_ground, col_ground = sicd.get_ground_resolution()
         return cls(Resolution=(row_ground, col_ground))
@@ -488,7 +490,7 @@ class ExploitationFeaturesType(Serializable):
                 Product=ExploitationFeaturesProductType.from_sicd(sicd[0]))
 
         if not isinstance(sicd, SICDType):
-            raise TypeError('Requires SICDType instance, got type {}'.format(type(sicd)))
+            raise TypeError(_sicd_type_text.format(type(sicd)))
         return cls(
             Collections=[
                 CollectionType.from_calculator(
